#!/usr/bin/env python3
import re
from urllib import request
from bs4 import BeautifulSoup


def scrapHREF(url):
    html = request.urlopen(url).read()
    soup = BeautifulSoup(html, features="html.parser")
    pdfs = soup.findAll("a", href=re.compile("pdf"))

    if len(pdfs) == 0:
        raise Exception('No PDFs found at ' + url)

    return pdfs



from setuptools import setup

setup(name='downloadpdf',
      version='1.0.1',
      description='Downloads PDFs from URL',
      url='https://codeanit.com/',
      author='Anit Shrestha Manandhar',
      author_email='codeanit@gmail.com',
      license='MIT',
      packages=['downloadpdf'],
      zip_safe=False,
      python_requires='>=3.6',
      install_requires=['beautifulsoup4==4.10.0'])



#!/usr/bin/env python3
import logging
import os
from urllib import request
from urllib.parse import unquote


def downloadPDF(url, storage, pdfs):

    for link in pdfs:
        decodedFileName = link.get('href')
        unquoteFileName = unquote(decodedFileName)

        request.urlretrieve(url + '/' + decodedFileName,
                            storage + '/' + unquoteFileName)

        if (os.environ.get('DEBUG')):
            break
